@@ -75,7 +75,7 @@ class Monitor:
                 record_path = path_fix + _ + '_monitor.xlsx'
                 wb = openpyxl.load_workbook(record_path)
                 ws = wb.active
-                error_times = ws['C1']
+                error_times = ws['C1'].value
                 error_time_list.append(error_times)
                 wb.close()
 
